@@ -50,13 +50,25 @@ class scrape(object):
         else:
             news_urls = urls
         
+        print("\nSearch Level {:<d}:".format(search_level), end="")
         if search_level==0:
-            print("\nSearch Level 0: Quick search of URLs for:", words)
+            print(" Screening URLs for search words")
+            print("   URLs must contain one or more of:", end="")
         else:
-            print("\nSearch Level 1: ",
-                  "Deep download and search of all qualified articles for:",
-                  words)
-        print("")   
+            print(" No URL Screening")
+            print("   Deep Search for Articles containing: ", 
+                  end="")
+        i=0
+        for word in words:
+            i += 1
+            if i < len(words):
+                if search_type == 'or':
+                    print(word+" or ", end="")
+                else:
+                    print(word+" & ", end="")
+            else:
+                print(word)
+                    
         df_articles = pd.DataFrame(columns=['agency', 'url', 'length', 
                                             'keywords', 'title', 'summary', 
                                             'story'])
@@ -66,65 +78,80 @@ class scrape(object):
             paper   = newspaper.build(url, memoize_articles=False, \
                                    fetch_images=False, request_timeout=20)
             if display:
-                print("{:>6d} Articles available from {:<s} on {:<10s}:".
+                print("\n{:>6d} Articles available from {:<s} on {:<10s}:".
                       format(paper.size(), agency.upper(), today))
             article_collection = []
-            for word in words:
-                word = word.lower()
-                for article in paper.articles:
-                    url_lower = article.url.lower()
-                    # Exclude articles that are in a language other then en
-                    # or contains mostly video or pictures
-                    # search_level 0 only searchs the url for keywords
-                    # search_level 0 only downloads articles with a 
-                    # keyword in their url.
-                    if search_level == 0 and url_lower.find(word) < 0:
+            for article in paper.articles:
+                url_lower = article.url.lower()
+                # Exclude articles that are in a language other then en
+                # or contains mostly video or pictures
+                # search_level 0 only downloads articles with at least
+                # one of the key words in its URL
+                # search_level 1 download all articles that appear to be
+                # appear to be in English and are not mainly photos or
+                # videos.
+                # With either search level, if an article is downloaded
+                # it is scanned to see if it contains the search words
+                # It is also compared to other articles to verify that
+                # it is not a duplicate of another article.
+                
+                 # Special Filters for some Agencies
+                if agency=='cbs-news':
+                    if  url_lower.find('.com') >=0 :
+                        # secure-fly are duplicates of http
+                        if article.url.find('secure-fly')>=0:
+                            continue
+                if agency=='usa-today':
+                    if url_lower.find('tunein.com') >= 0:
                         continue
-                    if url_lower.find('.video/')   >=0 or \
-                       url_lower.find('/video')    >=0 or \
-                       url_lower.find('/picture')  >=0 or \
-                       url_lower.find('.pictures/')>=0 or \
-                       url_lower.find('/photo')    >=0 or \
-                       url_lower.find('.photos/')  >=0 or \
-                       url_lower.find('espanol')   >=0 or \
-                       url_lower.find('.mx/' )     >=0 or \
-                       url_lower.find('/mx.' )     >=0 or \
-                       url_lower.find('.fr/' )     >=0 or \
-                       url_lower.find('/fr.' )     >=0 or \
-                       url_lower.find('.de/' )     >=0 or \
-                       url_lower.find('/de.' )     >=0 or \
-                       url_lower.find('.it/' )     >=0 or \
-                       url_lower.find('/it.' )     >=0 or \
-                       url_lower.find('.gr/' )     >=0 or \
-                       url_lower.find('/gr.' )     >=0 or \
-                       url_lower.find('.se/' )     >=0 or \
-                       url_lower.find('/se.' )     >=0 or \
-                       url_lower.find('.es/' )     >=0 or \
-                       url_lower.find('/es.' )     >=0 :
+                if agency=='huffington':
+                    # Ignore huffington if it's not .com
+                    if url_lower.find('.com') < 0:
+                        continue
+                    
+                # Filter Articles that are primarily video, film or not en
+                if url_lower.find('.video/')   >=0 or \
+                   url_lower.find('/video')    >=0 or \
+                   url_lower.find('/picture')  >=0 or \
+                   url_lower.find('.pictures/')>=0 or \
+                   url_lower.find('/photo')    >=0 or \
+                   url_lower.find('.photos/')  >=0 or \
+                   url_lower.find('espanol')   >=0 or \
+                   url_lower.find('.mx/' )     >=0 or \
+                   url_lower.find('/mx.' )     >=0 or \
+                   url_lower.find('.fr/' )     >=0 or \
+                   url_lower.find('/fr.' )     >=0 or \
+                   url_lower.find('.de/' )     >=0 or \
+                   url_lower.find('/de.' )     >=0 or \
+                   url_lower.find('.it/' )     >=0 or \
+                   url_lower.find('/it.' )     >=0 or \
+                   url_lower.find('.gr/' )     >=0 or \
+                   url_lower.find('/gr.' )     >=0 or \
+                   url_lower.find('.se/' )     >=0 or \
+                   url_lower.find('/se.' )     >=0 or \
+                   url_lower.find('.es/' )     >=0 or \
+                   url_lower.find('/es.' )     >=0 :
                        continue
-                    if agency=='usa-today':
-                        if url_lower.find('tunein.com') <0:
-                            article_collection.append(article.url)
-                        continue
-                    if agency=='huffington':
-                        if url_lower.find('.com') >=0:
-                            article_collection.append(article.url)
-                        continue
-                    if agency=='cbs-news':
-                        if  url_lower.find('.com') >=0 :
-                            # secure-fly are duplicates of http
-                            if article.url.find('secure-fly')>=0:
-                                     continue
-                            article_collection.append(article.url)
-                        continue
+               
+                # Filter if search_level == 0, URL quick search
+                if search_level == 0:
+                    # Verify url contains at least one of the key words
+                    found_it = False
+                    for word in words:
+                        j = url_lower.find(word)
+                        if j>= 0:
+                            found_it = True
+                            break
+                    if found_it:
+                        # Article contains words and passes filters
+                        # Save this article for full review
+                        article_collection.append(article.url)
+                else:
+                    #  No URL screening, Save for full review
                     article_collection.append(article.url)
             n_to_review = len(article_collection)
             if display:
-                print("{:>6d} Selected for download and review. Note that".
-                      format(n_to_review))
-                print("       download requests can fail, and multiple")
-                print("       copies of the same article are common.")
-                print("       These are filtered and saved as a single copy.")
+                print("{:>6d} Selected for download".format(n_to_review))
             
             for article_url in article_collection:
                 article = Article(article_url)
@@ -148,7 +175,8 @@ class scrape(object):
                         # Double wait time if needed for next exception
                         stop_sec = stop_sec+1
                 if n != 99:
-                    print("\nCannot download:", article_url[0:79])
+                    if display:
+                        print("Cannot download:", article_url[0:79])
                     n_to_review -= 1
                     continue
                 article.nlp()
@@ -156,25 +184,26 @@ class scrape(object):
                 title    = article.title
                 summary  = article.summary
                 story    = article.text
-                found_it = False
                 story_lower_case = story.lower()
                 if search_type == 'or':
-                    # Verify the story contains at least one of the key words
-                    for i in range(len(words)):
-                        j = story_lower_case.find(words[i].lower())
+                    found_it = False
+                    # Verify the url contains at least one of the key words
+                    for word in words:
+                        j = story_lower_case.find(word)
                         if j>= 0:
                             found_it = True
-                            continue
-                else: # search type 'and'
+                            break
+                else: 
+                    # search type 'and'
                     found_it = True
-                    for i in range(len(words)):
-                        j = story_lower_case.find(words[i].lower())
+                    for word in words:
+                        j = story_lower_case.find(word)
                         if j < 0:
                             found_it = False
-                            continue
-                if not(found_it):
-                    n_to_review -= 1
-                else:
+                            break
+                if found_it:
+                    # Article contains words and passes filters
+                    # Save this article for later full review
                     length   = len(story)
                     df_story = pd.DataFrame([[agency, url, length, keywords,
                                               title, summary, story]], 
@@ -193,21 +222,48 @@ class scrape(object):
                                 continue
                         if not(same_story):
                             df_articles  = df_articles.append(df_story)
+                else:
+                    n_to_review -= 1
+                    
                 print("=", end='')
             n_articles[agency] = [n_to_review, len(article_collection)]
         if display:
-            print("")
+            print("\n\nArticles Selected by Agency:")
             for agency in news_urls:
                 ratio = str(n_articles[agency][0]) + "/" + \
                         str(n_articles[agency][1])
-                ratio = ratio + " articles selected from "+agency.upper()
-                print(ratio)
-            print("\nTotal Articles Collected on "+today+":", 
+                ratio = ratio
+                print("{:>10s} Articles from {:<s}".
+                      format(ratio, agency.upper()))
+            print("\nArticles Collected on "+today+":", 
                       df_articles.shape[0],'from', 
-                      df_articles['agency'].nunique(), "News Agencies.")
+                      df_articles['agency'].nunique(), "Agencies.")
+            print("\nSize    Agency    Title")
+            print("*{:->78s}*".format("-"))
+            for i in range(df_articles.shape[0]):
+                k = len(df_articles['title'].iloc[i])
+                if k > 63:
+                    for j in range(25):
+                        k = 63-j
+                        if df_articles['title'].iloc[i][k] == " ":
+                            break
+                
+                    print("{:>5d} {:<10s} {:<63s}".
+                          format(df_articles['length'].iloc[i], 
+                                 df_articles['agency'].iloc[i],
+                                 df_articles['title' ].iloc[i][0:k]))
+                    if len(df_articles['title'].iloc[i])>63:
+                        print("                {:<60s}".
+                              format(df_articles['title'].iloc[i][k:120]))
+                else:
+                    print("{:>5d} {:<10s} {:<s}".
+                          format(df_articles['length'].iloc[i], 
+                                 df_articles['agency'].iloc[i],
+                                 df_articles['title' ].iloc[i]))
+                print("")
+            print("*{:->78s}*".format("-"))
         return df_articles
 
-    
     def clean_html(html):
         # First we remove inline JavaScript/CSS:
         pg = re.sub(r"(?is)<(script|style).*?>.*?(</\1>)", "", html.strip())
